@@ -23,7 +23,7 @@ use vars qw($VERSION);
 use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::Canon;
 
-$VERSION = '1.39';
+$VERSION = '1.40';
 
 sub ProcessCanonVRD($$;$);
 sub WriteCanonVRD($$;$);
@@ -1427,15 +1427,16 @@ my $blankFooter = "CANON OPTIONAL DATA\0" . ("\0" x 42) . "\xff\xd9";
     4 => 'CropY',
     5 => 'CropWidth',
     6 => 'CropHeight',
+    7 => 'CropRotation',
     8 => {
-        Name => 'CropRotation',
+        Name => 'CropAngle',
         Format => 'double',
         PrintConv => 'sprintf("%.7g",$val)',
         PrintConvInv => '$val',
     },
-    0x0a => 'CropOriginalWidth',
-    0x0b => 'CropOriginalHeight',
-    # 0x0c double - value: 100
+    10 => 'CropOriginalWidth',
+    11 => 'CropOriginalHeight',
+    # 12 double - value: 100
 );
 
 # DR4 Stamp Tool tags (ref PH)
